Class: Google::Apis::CloudresourcemanagerV2::Operation
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV2::Operation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v2/classes.rb,
lib/google/apis/cloudresourcemanager_v2/representations.rb,
lib/google/apis/cloudresourcemanager_v2/representations.rb
Overview
This resource represents a long-running operation that is the result of a network API call.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
If the value is
false, it means the operation is still in progress. -
#error ⇒ Google::Apis::CloudresourcemanagerV2::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation.
-
#name ⇒ String
The server-assigned name, which is only unique within the same service that originally returns it.
-
#response ⇒ Hash<String,Object>
The normal, successful response of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
832 833 834 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 832 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
If the value is false, it means the operation is still in progress. If true
, the operation is completed, and either error or response is available.
Corresponds to the JSON property done
793 794 795 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 793 def done @done end |
#error ⇒ Google::Apis::CloudresourcemanagerV2::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
804 805 806 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 804 def error @error end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation. It typically contains
progress information and common metadata such as create time. Some services
might not provide such metadata. Any method that returns a long-running
operation should document the metadata type, if any.
Corresponds to the JSON property metadata
812 813 814 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 812 def @metadata end |
#name ⇒ String
The server-assigned name, which is only unique within the same service that
originally returns it. If you use the default HTTP mapping, the name should
be a resource name ending with operations/unique_id`.
Corresponds to the JSON propertyname`
819 820 821 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 819 def name @name end |
#response ⇒ Hash<String,Object>
The normal, successful response of the operation. If the original method
returns no data on success, such as Delete, the response is google.protobuf.
Empty. If the original method is standard Get/Create/Update, the
response should be the resource. For other methods, the response should have
the type XxxResponse, where Xxx is the original method name. For example,
if the original method name is TakeSnapshot(), the inferred response type is
TakeSnapshotResponse.
Corresponds to the JSON property response
830 831 832 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 830 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
837 838 839 840 841 842 843 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 837 def update!(**args) @done = args[:done] if args.key?(:done) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @response = args[:response] if args.key?(:response) end |