Class: Google::Apis::CloudresourcemanagerV2::ProjectCreationStatus
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV2::ProjectCreationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v2/classes.rb,
lib/google/apis/cloudresourcemanager_v2/representations.rb,
lib/google/apis/cloudresourcemanager_v2/representations.rb
Overview
A status object which is used as the metadata field for the Operation
returned by CreateProject. It provides insight for when significant phases of
Project creation have completed.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Creation time of the project creation workflow.
-
#gettable ⇒ Boolean
(also: #gettable?)
True if the project can be retrieved using GetProject.
-
#ready ⇒ Boolean
(also: #ready?)
True if the project creation process is complete.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectCreationStatus
constructor
A new instance of ProjectCreationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectCreationStatus
Returns a new instance of ProjectCreationStatus.
965 966 967 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 965 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Creation time of the project creation workflow.
Corresponds to the JSON property createTime
950 951 952 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 950 def create_time @create_time end |
#gettable ⇒ Boolean Also known as: gettable?
True if the project can be retrieved using GetProject. No other operations on
the project are guaranteed to work until the project creation is complete.
Corresponds to the JSON property gettable
956 957 958 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 956 def gettable @gettable end |
#ready ⇒ Boolean Also known as: ready?
True if the project creation process is complete.
Corresponds to the JSON property ready
962 963 964 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 962 def ready @ready end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
970 971 972 973 974 |
# File 'lib/google/apis/cloudresourcemanager_v2/classes.rb', line 970 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @gettable = args[:gettable] if args.key?(:gettable) @ready = args[:ready] if args.key?(:ready) end |